      program carlomat
c----------------------------------------------------------------------c
c Automized calculation of the cross section of SM process
c
c                 f_1 f_2 -> f_3 f_4 ... f_next
c
c Karol Kolodziej, University of Silesia, karol.kolodziej@us.edu.pl
c 9 February, 2006; modified 
c----------------------------------------------------------------------c

      use mytypes
      use extpart
      use schkins
      use tchkins
      use gchkins
      use psgen_info

      implicit none

      character(80) :: process

c Specify a process below. The maximum number of external particles 
c is 12. 
c Standard Model particles include (notation adopted from MadGraph)
c     Quarks:   d u s c b t d~ u~ s~ c~ b~ t~
c     Leptons:  e- mu- ta- e+ mu+ ta+ ve vm vt ve~ vm~ vt~
c     Bosons:   g a z w+ w- h
c Other particles:
c     Nucleons: p, p~, n, n~
c     Mesons: pi-, pi+, pi0, k-, k+, k0, k0~, rho-, rho+, rho0, ome, phi,
c             rho1, rho2
c
c Define process:

      process='e+ e- -> b mu+ vm b~ mu- vm~' 

c Generate kinemtics with PSGen, ipsgen=1/else it will be generated with carlomat.

      ipsgen=1

c If ipsgen=1 then, after having generated code for the matrix element with carlomat,
c go to PSGen_1.1/code_generation and execute a command make code/
c else select the values of the flags ischnl, igchnl and itchnl below and
c generate code for the matrix element and kinematics with carlomat.

c Generate s-channel kinemtics
c ischnl=1 (yes, kinematics based on topologies of the Feynman
c diagrams, possible for any proces, compilation and
c computation of the generated MC kinematical routines may be very time 
c consuming)/2 (yes, generate kinematics of the considered process with PSGen 
c and copy it to mc_computation of carkomat_4.4 by appriately modifying makefile
c of PSGen_1.0/code_generation)/else (no)?
      
      ischnl=1

c Generate single photon radiation kinematics, for processes with one photon 
c or gluon in the final state, igchnl=1 (yes)/2 (yes, taking into account
c poles listed in genps.dat and information collected in particles.dat)/else (no)?

      igchnl=0

c Generate t-channel kinematics, for processes with identical fermion-antifermion
c pairs in the initial and final state, itchnl=1 (yes, only for double t-channel 
c poles)/2 (yes, both for double and single t-channel poles))/else (no)?

      itchnl=0

c Use quartic precision for the particle four momenta, masses and widths,
c iqprec=1 (yes)/else (no)?:
 
      iqprec=0

c Short name of the process:

      prcsnm='auto'  ! If prcsnm='auto' then it is made automatically.
 
c Take into account photon radiation from the initial state only (isr=1)/
c final state only (isr=2)/ both (isr=else)? Relevant only for processes with
c external photons. Makes sens only if ISR and FSR form gauge independent
c subsets of the Feynman diagrams

      isr=0

c Monte Carlo summing over polarizations: imcs=1 (yes)/else (no)?

      imcs=1

c Take into account the Cabibbo-Kobayashi-Maskawa mixing: ickm=1(yes)/else(no)?

      ickm=0

c Include the anomalous Wtb coupling: iwtb=1 (Yes)/else (No)? 
c (see K. Kolodziej, Phys. Lett. B584 (2004) 89)

      iwtb=0

      call readpart(process)

c      if (ischnl == 2) then
       iquadp=iqprec
       itchnl2=itchnl
       igchnl2=igchnl
       call read_process(process)
       call genps(nfspt)
       nkins=nkins2
       nkint=nkint2
       igind=igind2
c      end if

      call genmat

      end

